summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmisosurfaceedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmisosurfaceedit.h')
-rw-r--r--kpovmodeler/pmisosurfaceedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmisosurfaceedit.h b/kpovmodeler/pmisosurfaceedit.h
index c0a1dda4..6e6216cc 100644
--- a/kpovmodeler/pmisosurfaceedit.h
+++ b/kpovmodeler/pmisosurfaceedit.h
@@ -45,9 +45,9 @@ class PMIsoSurfaceEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMIsoSurfaceEdit with tqparent and name
*/
- PMIsoSurfaceEdit( TQWidget* tqparent, const char* name = 0 );
+ PMIsoSurfaceEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -45,9 +45,9 @@ class PMIsoSurfaceEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMIsoSurfaceEdit with tqparent and name
+ * Creates a PMIsoSurfaceEdit with parent and name
*/